==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>L&apos;authentification a expiré</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Le disque est occupé, et ne peut donc pas être démonté maintenant</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Le disque est occupé, impossible de l&apos;éjecter maintenant</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>L&apos;appareil est occupé et ne peut pas être éjecté maintenant</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>L&apos;appareil est occupé et ne peut pas être retiré maintenant</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Le périphérique n&apos;a pas été retiré en toute sécurité</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Cliquer sur &quot;Supprimer en toute sécurité&quot; et ensuite déconnecter-le </translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">L&apos;appareil est occupé et ne peut pas être éjecté maintenant</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">L&apos;appareil est occupé et ne peut pas être retiré maintenant</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossible de démonter l&apos;appareil</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Le disque est monté par l&apos;utilisateur &quot;% 1&quot;, vous ne pouvez pas le démonter.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossible de trouver le périphérique monté</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disques</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Tout éjecter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>L&apos;appareil a été retiré en toute sécurité</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Vous n&apos;êtes pas autorisé à accéder à ce dossier</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scanner l&apos;appareil, l&apos;arrêter ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.9.orig.tar.xz: dde-file-manager-5.6.9/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>L&apos;authentification a expiré</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Le disque est occupé, et ne peut donc pas être démonté maintenant</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Le disque est occupé, impossible de l&apos;éjecter maintenant</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>L&apos;appareil est occupé et ne peut pas être éjecté maintenant</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>L&apos;appareil est occupé et ne peut pas être retiré maintenant</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Le périphérique n&apos;a pas été retiré en toute sécurité</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Cliquez sur &quot;Supprimer en toute sécurité&quot; et ensuite déconnectez-le </translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Impossible de démonter l&apos;appareil</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Le disque est monté par l&apos;utilisateur &quot;% 1&quot;, vous ne pouvez pas le démonter.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Impossible de trouver le périphérique monté</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disques</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disque</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Tout éjecter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>L&apos;appareil a été retiré en toute sécurité</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Accès refusé</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Vous n&apos;êtes pas autorisé à accéder à ce dossier</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scanner l&apos;appareil, l&apos;arrêter ?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Arrêter</translation>
    </message>
</context>
</TS>
